@@ -1,8 +1,7 @@
 from dataclasses import dataclass
-from functools import lru_cache
+from functools import cached_property
 from typing import Any, Optional
 
-from kedro.framework.context import KedroContext
 from kedro.framework.session import KedroSession
 
 from kedro_azureml.config import KedroAzureMLConfig
@@ -21,11 +20,14 @@ class KedroContextManager:
         self.extra_params = extra_params
         self.env = env
         self.package_name = package_name
-        self.context: Optional[KedroContext] = None
         self.session: Optional[KedroSession] = None
 
-    @property
-    @lru_cache()
+    @cached_property
+    def context(self):
+        assert self.session is not None, "Session not  initialized yet"
+        return self.session.load_context()
+
+    @cached_property
     def plugin_config(self) -> KedroAzureMLConfig:
         return KedroAzureMLConfig.parse_obj(self.context.config_loader.get("azureml*"))
 
@@ -33,7 +35,6 @@ class KedroContextManager:
         self.session = KedroSession.create(
             self.package_name, env=self.env, extra_params=self.extra_params
         )
-        self.context = self.session.load_context()
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
